v1

package
v0.0.0-...-93e8ec0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Nov 30, 2023 License: AGPL-3.0 Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var DataModifier_ServiceDesc = grpc.ServiceDesc{
	ServiceName: "datamodifier.DataModifier",
	HandlerType: (*DataModifierServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "AddAbsenceStatus",
			Handler:    _DataModifier_AddAbsenceStatus_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "datamodifier.proto",
}

DataModifier_ServiceDesc is the grpc.ServiceDesc for DataModifier service. It's only intended for direct use with grpc.RegisterService, and not to be introspected or modified (even as a copy)

var File_datamodifier_proto protoreflect.FileDescriptor

Functions

func RegisterDataModifierServer

func RegisterDataModifierServer(s grpc.ServiceRegistrar, srv DataModifierServer)

Types

type DataModifierClient

type DataModifierClient interface {
	// AddAbsenceStatus allows to add an absence status to the user name.
	AddAbsenceStatus(ctx context.Context, in *SourceData, opts ...grpc.CallOption) (*ModifiedData, error)
}

DataModifierClient is the client API for DataModifier service.

For semantics around ctx use and closing/ending streaming RPCs, please refer to https://pkg.go.dev/google.golang.org/grpc/?tab=doc#ClientConn.NewStream.

type DataModifierServer

type DataModifierServer interface {
	// AddAbsenceStatus allows to add an absence status to the user name.
	AddAbsenceStatus(context.Context, *SourceData) (*ModifiedData, error)
	// contains filtered or unexported methods
}

DataModifierServer is the server API for DataModifier service. All implementations must embed UnimplementedDataModifierServer for forward compatibility

type ModifiedData

type ModifiedData struct {
	ModifiedUserData *UserData `protobuf:"bytes,1,opt,name=modified_user_data,json=modifiedUserData,proto3" json:"modified_user_data,omitempty"`
	// contains filtered or unexported fields
}

ModifiedData defines the fields in a /DataModifier/AddAbsenceStatus method response.

func (*ModifiedData) Descriptor deprecated

func (*ModifiedData) Descriptor() ([]byte, []int)

Deprecated: Use ModifiedData.ProtoReflect.Descriptor instead.

func (*ModifiedData) GetModifiedUserData

func (x *ModifiedData) GetModifiedUserData() *UserData

func (*ModifiedData) ProtoMessage

func (*ModifiedData) ProtoMessage()

func (*ModifiedData) ProtoReflect

func (x *ModifiedData) ProtoReflect() protoreflect.Message

func (*ModifiedData) Reset

func (x *ModifiedData) Reset()

func (*ModifiedData) String

func (x *ModifiedData) String() string

type SourceData

type SourceData struct {

	// User data
	UserData *UserData `protobuf:"bytes,1,opt,name=user_data,json=userData,proto3" json:"user_data,omitempty"`
	// Time period
	TimePeriod *TimePeriod `protobuf:"bytes,2,opt,name=time_period,json=timePeriod,proto3" json:"time_period,omitempty"`
	// contains filtered or unexported fields
}

SourceData defines the fields in a /DataModifier/AddAbsenceStatus method request to adding an absence status to user data.

func (*SourceData) Descriptor deprecated

func (*SourceData) Descriptor() ([]byte, []int)

Deprecated: Use SourceData.ProtoReflect.Descriptor instead.

func (*SourceData) GetTimePeriod

func (x *SourceData) GetTimePeriod() *TimePeriod

func (*SourceData) GetUserData

func (x *SourceData) GetUserData() *UserData

func (*SourceData) ProtoMessage

func (*SourceData) ProtoMessage()

func (*SourceData) ProtoReflect

func (x *SourceData) ProtoReflect() protoreflect.Message

func (*SourceData) Reset

func (x *SourceData) Reset()

func (*SourceData) String

func (x *SourceData) String() string

type TimePeriod

type TimePeriod struct {

	// Start timestamp.
	DateFrom string `protobuf:"bytes,1,opt,name=date_from,json=dateFrom,proto3" json:"date_from,omitempty"`
	// Stop timestamp.
	DateTo string `protobuf:"bytes,2,opt,name=date_to,json=dateTo,proto3" json:"date_to,omitempty"`
	// contains filtered or unexported fields
}

A TimePeriod is a time interval of the search. Default time format is "2006-01-02T15:04:05".

func (*TimePeriod) Descriptor deprecated

func (*TimePeriod) Descriptor() ([]byte, []int)

Deprecated: Use TimePeriod.ProtoReflect.Descriptor instead.

func (*TimePeriod) GetDateFrom

func (x *TimePeriod) GetDateFrom() string

func (*TimePeriod) GetDateTo

func (x *TimePeriod) GetDateTo() string

func (*TimePeriod) ProtoMessage

func (*TimePeriod) ProtoMessage()

func (*TimePeriod) ProtoReflect

func (x *TimePeriod) ProtoReflect() protoreflect.Message

func (*TimePeriod) Reset

func (x *TimePeriod) Reset()

func (*TimePeriod) String

func (x *TimePeriod) String() string

type UnimplementedDataModifierServer

type UnimplementedDataModifierServer struct {
}

UnimplementedDataModifierServer must be embedded to have forward compatible implementations.

func (UnimplementedDataModifierServer) AddAbsenceStatus

type UnsafeDataModifierServer

type UnsafeDataModifierServer interface {
	// contains filtered or unexported methods
}

UnsafeDataModifierServer may be embedded to opt out of forward compatibility for this service. Use of this interface is not recommended, as added methods to DataModifierServer will result in compilation errors.

type UserData

type UserData struct {

	// Name.
	DisplayName string `protobuf:"bytes,1,opt,name=display_name,json=displayName,proto3" json:"display_name,omitempty"`
	// Email.
	Email string `protobuf:"bytes,2,opt,name=email,proto3" json:"email,omitempty"`
	// Mobile phone.
	MobilePhone string `protobuf:"bytes,3,opt,name=mobile_phone,json=mobilePhone,proto3" json:"mobile_phone,omitempty"`
	// Work phone.
	WorkPhone string `protobuf:"bytes,4,opt,name=work_phone,json=workPhone,proto3" json:"work_phone,omitempty"`
	// contains filtered or unexported fields
}

A UserData contains information about the user.

func (*UserData) Descriptor deprecated

func (*UserData) Descriptor() ([]byte, []int)

Deprecated: Use UserData.ProtoReflect.Descriptor instead.

func (*UserData) GetDisplayName

func (x *UserData) GetDisplayName() string

func (*UserData) GetEmail

func (x *UserData) GetEmail() string

func (*UserData) GetMobilePhone

func (x *UserData) GetMobilePhone() string

func (*UserData) GetWorkPhone

func (x *UserData) GetWorkPhone() string

func (*UserData) ProtoMessage

func (*UserData) ProtoMessage()

func (*UserData) ProtoReflect

func (x *UserData) ProtoReflect() protoreflect.Message

func (*UserData) Reset

func (x *UserData) Reset()

func (*UserData) String

func (x *UserData) String() string

Jump to